function x=molrat(rh,t)
% molrat	- Does a humidity calculation in moles
% function x=molrat(rh,t)
% Argument List:
% Argument   Gives
%    rh     the relative humidity as a fraction.
%    t      the temperature in the units of Tdeg
% x is returned as the molar ratio of water to dry air.
% Ex: humidity
%     molrat(.5 50)
x=rh*vappr(t,3)/101.325;
x=x/(1-x);
